@@ -450,7 +450,27 @@ def agrupamiento_dbscan(X,pdf,R,Min):
                 Number_of_data.append(clust_set.shape[0]);
 
     return [labels,realClusterNum,Number_of_data,new_pdf]
-    
+#### Función para hacer los gráficos ##########
+def graficosns(df,columna,option1,option2,binss,colore):   #(df:tabla, columna, option1: kde True or False
+                                                             #,option2: discrete True or False, binss: numero de bins,
+                                                            # col: color)
+    f, ax= plt.subplots(2,1,figsize=(10,7),sharex=True,gridspec_kw={"height_ratios": (.35, .55)})
+    sns.set_style("whitegrid")
+    red_cir = dict(markerfacecolor='maroon',marker='o',markersize=6)
+    sns.boxplot(y="Tipo",x=df[columna],data=df,ax=ax[0],
+                flierprops=red_cir,palette=colore).set_title(columna)
+    sns.stripplot(y="Tipo",x=df[columna],data=df,ax=ax[0],jitter=0.15,size=2.5,palette=colore)
+    ax[0].grid(True, color='lightgrey',linestyle='--')
+    ax[0].set(xlabel='')
+    ax[0].set(ylabel='')
+    sns.histplot(data=df,x=columna,hue='Tipo',element='bars',palette=colore,
+                 ax=ax[1],kde=option1,discrete=option2,bins=binss)     
+    ax[1].set(xlabel='')
+    ax[1].set(ylabel='Cantidad')
+    #ax[1].set_title(columna)
+    ax[1].grid(True, color='lightgrey',linestyle='--')
+    plt.show()   
+
 def indexacion(df,mini,maxi):
     years1=[]
     for i in range(mini,maxi,10):
